pub struct Plane3 {
pub point: Vec3,
pub normal: Vec3,
}Expand description
Infinite plane defined by a point on the plane and a (unit) normal.
Fields
point: Vec3A point on the plane.
normal: Vec3Unit normal.
Implementations
Sourceimpl Plane3
impl Plane3
Sourcepub fn horizontal(z: f64) -> Self
pub fn horizontal(z: f64) -> Self
Constructs a horizontal plane at height z.
Sourcepub fn signed_distance(&self, p: Vec3) -> f64
pub fn signed_distance(&self, p: Vec3) -> f64
Signed distance from p to the plane (positive on normal side).
Sourcepub fn intersect_ray(&self, ray: &Ray3) -> Option<f64>
pub fn intersect_ray(&self, ray: &Ray3) -> Option<f64>
Intersect with a ray. Returns the non-negative t of intersection
or None if parallel or behind the ray origin.